@@ -424,7 +424,8 @@ if (committed.dimension_m > 250)
     gtk_statusbar_push(GTK_STATUSBAR(statusb_edita),0,"  Warning: Matrix Display is not accurate for dimensions larger then 250 x 250");
 
 /**************** connect signals  begin   */
-g_signal_connect ((gpointer) window_edit_a, "delete_event", G_CALLBACK (on_edit_a_menu_quit_activate),NULL);
+/* g_signal_connect ((gpointer) window_edit_a, "delete_event", G_CALLBACK (on_delete_event_do),NULL);*/
+g_signal_connect ((gpointer) button_quit_ed, "destroy", G_CALLBACK(on_edit_a_menu_destroy_activate),NULL);
 g_signal_connect ((gpointer) button_quit_ed, "clicked", G_CALLBACK(on_edit_a_menu_quit_activate),NULL);
 if (matvalue!=NULL) { /* do not activate drawings calls if no memory for buffers */
 g_signal_connect (G_OBJECT (matarea), "expose_event",  G_CALLBACK (draw_matarea_callback), NULL);
@@ -460,6 +461,16 @@ void
 on_edit_a_menu_quit_activate   (GtkMenuItem  *menuitem, gpointer  user_data)
 {
 if(is_debug==1) printf("on_edit_a_menu_quit_activate: quit\n");
+gtk_widget_destroy(GTK_WIDGET(window_edit_a));
+if(is_debug==1) printf("on_edit_a_menu_quit_activate: exiting\n");   
+}
+/*********************************/
+
+/* response to destroy window event */
+void
+on_edit_a_menu_destroy_activate   (GtkWidget  *ww, gpointer  user_data)
+{
+if(is_debug==1) printf("on_edit_a_menu_destroy_activate: \n");
 /* save block number */
 pea.block=a_displayed_block;
 /* free space of the graphic buffers */
@@ -467,8 +478,7 @@ free(matvalue);
 free(rgb_matvalue);
 free(as);
 is_edit_a_open=0;  /* 0=not open  1=open */
-gtk_widget_destroy(GTK_WIDGET(window_edit_a));
-if(is_debug==1) printf("on_edit_a_menu_quit_activate: exiting Edit A; preferences: %d %d %d %d %g %d\n",pea.block,pea.is_positive,pea.is_color,pea.is_user,pea.contrast_value,pea.is_range_type);   
+if(is_debug==1) printf("on_edit_a_menu_destroy_activate: exiting Edit A; preferences: %d %d %d %d %g %d\n",pea.block,pea.is_positive,pea.is_color,pea.is_user,pea.contrast_value,pea.is_range_type);
 }
 /*********************************/
 
