@@ -24,11 +24,10 @@ integer qb    !Bqb mxn arrays 0= no Bqb arrays
 integer stat  !status output 0=ok, else =no memory 
 real(dpr) :: alpha,beta ! optional parameter for some examples
 !
-integer i,j,k,h
+integer i,j,h
 real(dpr) s
-real(dpr),allocatable,dimension(:,:)::ttt,ccc
 real(dpr),allocatable,dimension(:)::v
-real(dpr):: aa,bb,cc,dd,ee,binomial
+real(dpr):: binomial
 
 if (debug) write(*,*) "examples_setup: entering with num=",num," m=",m," n=",n," qa=",qa," qb=",qb," alpha=",alpha," beta=",beta
 
