@@ -34,6 +34,7 @@ void on_main_menu_exptel_activate (GtkMenuItem *, gpointer );
 void on_main_menu_savepad_activate (GtkMenuItem *, gpointer );
 void on_main_menu_clearpad_activate(GtkMenuItem *, gpointer );
 void on_main_menu_quit_activate    (GtkMenuItem *, gpointer );
+void on_main_menu_destroy_activate   (GtkWidget  * , gpointer );
 void on_main_menu_run_activate     (GtkMenuItem *, gpointer );
 void on_main_menu_stop_activate    (GtkMenuItem *, gpointer );
 void on_main_menu_edit_a_activate (GtkMenuItem *, gpointer);
@@ -108,6 +109,8 @@ void on_dimension_n_entry_changed  (GtkEntry *, gpointer );
 void on_array_n_entry_changed  (GtkEntry *, gpointer );
 void on_blocks_n_entry_changed  (GtkEntry *, gpointer);
 void on_parameters_quit_activate (GtkButton *, gpointer);
+void on_parameters_destroy_activate (GtkWidget  *ww, gpointer data);
+void on_examples_destroy_activate (GtkWidget  *ww, gpointer data);
 void on_examples_alpha_activate(GtkEntry *, gpointer );
 void on_examples_alpha_change(GtkEntry *, gpointer );
 void on_examples_alpha_e_change(GtkEntry *, gpointer );
@@ -120,6 +123,7 @@ void on_parameters_entry_itermax_changed (GtkEntry *, gpointer );
 void on_parameters_entry_interpmax_changed (GtkEntry *, gpointer );
 void on_parameters_entry_errmax_changed (GtkEntry *, gpointer );
 void on_pi_parameters_quit_activate (GtkButton *, gpointer);
+void on_pi_parameters_destroy_activate (GtkWidget  *ww, gpointer data);
 void on_pi_parameters_ok_activate (GtkButton *, gpointer);
 void on_pi_parameters_reset_activate (GtkButton *, gpointer);
 void on_parameters_entry_epspi_changed(GtkButton *, gpointer);
@@ -127,6 +131,7 @@ void on_parameters_entry_maxnc_changed(GtkButton *, gpointer);
 
 void update_completed(void);
 void invalidate_completed(void);
+gboolean on_delete_event_do   (GtkWidget *, GdkEvent *, gpointer);
 
 /* prototypes padwrite.c */
 void selection_uptodate(void);
