@@ -33,13 +33,11 @@ void append_fifo_(char *text)
 {
 struct timespec small_wait;
 small_wait.tv_sec=0;
-small_wait.tv_nsec=1000000; /* 1000000 nano sec = 1msec */
-
+small_wait.tv_nsec=1000000; /* 1000000 nano sec = 1+1msec */
 /* pthread_mutex_t my_mutex = PTHREAD_MUTEX_INITIALIZER; global */
 /* int fifosi=0, fifoin=0, fifoout=0, fifomax=50; global      */
 /* fifomax aumentato a 200 righe */
-pthread_testcancel();  /* cancellation point for fortran programs */
-pthread_mutex_lock( &my_mutex );
+pthread_mutex_lock( &my_mutex ); 
 strncpy(fifostr[fifoin],text,119);
 fifoin++;
 if (fifoin==fifomax) fifoin=0;
@@ -47,8 +45,10 @@ fifosi=1;
 /* this 1 msec delay is an empirical cure for a race condition ! */
 /* may be nanosleep can be used instead */
 /* system("/bin/sleep 0.001\n"); */
-nanosleep(&small_wait,NULL);
 pthread_mutex_unlock( &my_mutex );
+nanosleep(&small_wait,NULL);
+pthread_testcancel();  /* cancellation point for fortran programs */
+nanosleep(&small_wait,NULL);
 }
 /*********************************/
 
@@ -66,14 +66,15 @@ GtkTextMark *endmarkm;
 /* GtkWidget *statusb global */
 
 gdk_threads_enter ();
-if(is_completed ==1) {
 pthread_mutex_lock( &my_mutex );
+if(is_completed ==1) {
+/* pthread_mutex_lock( &my_mutex );*/
 is_completed=0;
  clean_statusb();
-pthread_mutex_unlock( &my_mutex ); 
+/* pthread_mutex_unlock( &my_mutex ); */
 }
 if (fifosi==1) {
-   pthread_mutex_lock( &my_mutex );
+/*   pthread_mutex_lock( &my_mutex );*/
    buffer = (GtkTextBuffer *) gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview));
    /* follow circularly fifoin, until you reach it and set fifosi=0 */
    gtk_text_buffer_get_end_iter(buffer,&enditerm);
@@ -86,8 +87,9 @@ if (fifosi==1) {
    gtk_text_buffer_get_end_iter(buffer,&enditerm);
    endmarkm=gtk_text_buffer_create_mark (buffer,"endmark",&enditerm,FALSE);
    gtk_text_view_scroll_to_mark (GTK_TEXT_VIEW(textview),endmarkm, 0,0,0,0);
-   pthread_mutex_unlock( &my_mutex);
+/*   pthread_mutex_unlock( &my_mutex);*/
   }
+ pthread_mutex_unlock( &my_mutex);
 gdk_threads_leave ();
 /* return 1 to let it run always in idle time loop until run is finished and fifo is void */
 if ((is_running==0)&&(is_completed==0)&&(fifosi==0)) return(0); else return(1);
@@ -138,10 +140,25 @@ char tmp[256];
                 if((algorithms_choice.fi_base1==1)&&(algorithms_choice.fi_natural==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(natural,basic,x(0)=I)");
                 if((algorithms_choice.fi_base1==1)&&(algorithms_choice.fi_traditional==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(traditional,basic,x(0)=I)");
                 if((algorithms_choice.fi_base1==1)&&(algorithms_choice.fi_Ubased==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(U-based,basic,x(0)=I)");
+
+
+
+                if((algorithms_choice.fi_base_u==1)&&(algorithms_choice.fi_natural==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(natural,basic,x user)");
+                if((algorithms_choice.fi_base_u==1)&&(algorithms_choice.fi_traditional==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(traditional,basic,x user)");
+                if((algorithms_choice.fi_base_u==1)&&(algorithms_choice.fi_Ubased==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(U-based,basic,x user)");
+
+
+
                 if((algorithms_choice.fi_shift==1)&&(algorithms_choice.fi_natural==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(natural,shift)");
                 if((algorithms_choice.fi_shift==1)&&(algorithms_choice.fi_traditional==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(traditional,shift)");
                 if((algorithms_choice.fi_shift==1)&&(algorithms_choice.fi_Ubased==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(U-based,shift)");
 
+                if((algorithms_choice.fi_shift_u==1)&&(algorithms_choice.fi_natural==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(natural,shift, x user)");
+                if((algorithms_choice.fi_shift_u==1)&&(algorithms_choice.fi_traditional==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(traditional,shift, x user)");
+                if((algorithms_choice.fi_shift_u==1)&&(algorithms_choice.fi_Ubased==1)) gtk_label_set_text (GTK_LABEL(label_s3),"Functional Iteration(U-based,shift, x user)");
+
+
+
                 break;
         case 4: if( algorithms_choice.is_base==1) gtk_label_set_text (GTK_LABEL(label_s3),"Invariant Subspace(basic)");
                 if( algorithms_choice.is_balzer==1) gtk_label_set_text (GTK_LABEL(label_s3),"Invariant Subspace(Balzer)");
